/*        
 * "Copyright (c) ReDCAD (Research Unit of Development and Control of Distributed Applications).
 * "Copyright (c) CISTER (Research  Centre in Real-Time Computing Systems) 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 *
 * IN NO EVENT SHALL REDCAD AND CISTER RESEARCH UNITS BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF REDCAD AND CISTER RESEARCH UNITS 
 * HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * REDCAD AND CISTER RESEARCH UNITS DISCLAIM ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND REDCAD AND CISTER RESEARCH UNITS HAVE NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 */
 /* Authors:    Maissa Ben Jamaa <mbenj@redcad.org>, Denis do Rosrio <dlr@isep.ipp.pt>
  *				Nouha Baccour <nabr@isep.ipp.pt>, Anis Koubaa <aska@isep.ipp.pt>,
  *				Mrio Alves <mjf@isep.ipp.pt>, Habib Youssef <habib.youssef@fsm.rnu.tn>, Leandro Becker <lbecker@das.ufsc.br>
  *				
  * Date: February 1 2010
  * Desc: ExpCtrApp v 1.0
 *              
 */ 
import java.sql.ResultSet;
import java.util.List;
import java.util.ArrayList;
import javax.swing.JPanel;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import java.awt.Dimension;
import org.jfree.chart.axis.*;
import org.jfree.chart.plot.*;
import org.jfree.chart.renderer.category.BarRenderer3D;
import org.jfree.data.category.CategoryDataset;
import org.jfree.data.category.DefaultCategoryDataset;

public class Graph extends JPanel {
    private DBconnection db = new DBconnection();
    String read;
    private String  reading;
    private List<String>  idSender = new ArrayList<String>();
    private List<String>  idReceiver = new ArrayList<String>();
    String expRun;
    String expId;

    public Graph(String experimentId, String experimentRun, List sender, List receiver, String read){
        super();
	
	reading = read;
	idSender = sender;
	idReceiver = receiver;
	expId = experimentId;
	expRun = experimentRun;
	
        JPanel jpanel = createdemoPanel();
        jpanel.setPreferredSize(new Dimension(1230, 700));
        add(jpanel);
    }

    private CategoryDataset createDataset(){
	db.open_a_connection();
        String sql;
        ResultSet result;
	DefaultCategoryDataset defaultcategorydataset = new DefaultCategoryDataset();

	sql = "SELECT " + reading + " FROM linkData WHERE exp_id = '" + expId + "' and exp_run_nbr = '" + expRun + "'";
	for (int j=0; j<idSender.size(); j++){
                for (int z=0; z<idReceiver.size(); z++){
			result = db.select(sql + " and src_id = " + idSender.get(j) + " and rcv_id = " +idReceiver.get(z)+";");
			float sun = 0;
			int cont = 0;
			if ((!idSender.get(j).toString().equals("1") && idReceiver.get(z).toString().equals("1")) || (idSender.get(j).toString().equals("1") && !idReceiver.get(z).toString().equals("1"))){
				try {
	       	                	while (result.next()) {
        	                    		sun += result.getFloat(1);
						cont ++;
        	                	}
		                } catch (Exception e) {e.printStackTrace();}
				if (sun != 0)
					defaultcategorydataset.addValue(sun/cont, "Average of " + reading, idSender.get(j).toString() + " -> " + idReceiver.get(z).toString());
			}
		}
	}
	db.close_a_connection();
        return defaultcategorydataset;
    }

    private JFreeChart createChart(CategoryDataset categorydataset){
	String read = reading;
	if (reading.equals("PACKET RECEPTION RATE"))
		read = "Packet Reception Rate (%)";
	else if (reading.equals("LQI"))
		read += "";
	else if (reading.equals("RSSI"))
		read += " (dBm)";
	else if (reading.equals("NOISE"))
		read = "Noise (dBm)";
	else if (reading.equals("SNR"))
		read += " (dB)";
	else if (reading.equals("HUMIDITY"))
		read = "Humidity (%)";
	else if (reading.equals("TEMPERATURE"))
		read = "Temperature (°C)";
	else if (reading.equals("LIGHT1"))
		read = "Light1";
	else if (reading.equals("LIGHT2"))
		read = "Light2";
	else if (reading.equals("VOLTAGE"))
		read = "Voltage (V)";
	
        JFreeChart jfreechart = ChartFactory.createBarChart3D("Graphs - Received Side", "Links (sender -> receiver)", read, categorydataset, PlotOrientation.VERTICAL, true, true, false);
        CategoryPlot categoryplot = jfreechart.getCategoryPlot();
        categoryplot.setDomainGridlinesVisible(true);
        CategoryAxis categoryaxis = categoryplot.getDomainAxis();
        categoryaxis.setCategoryLabelPositions(CategoryLabelPositions.createUpRotationLabelPositions(0.39269908169872414D));
	categoryaxis.setCategoryLabelPositions(CategoryLabelPositions.DOWN_45);
        BarRenderer3D barrenderer3d = (BarRenderer3D)categoryplot.getRenderer();
        barrenderer3d.setDrawBarOutline(false);
        return jfreechart;
    }

    public JPanel createdemoPanel(){
        JFreeChart jfreechart = createChart(createDataset());
        return new ChartPanel(jfreechart);
    }
}
