/*        
 * "Copyright (c) ReDCAD (Research Unit of Development and Control of Distributed Applications).
 * "Copyright (c) CISTER (Research  Centre in Real-Time Computing Systems) 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 *
 * IN NO EVENT SHALL REDCAD AND CISTER RESEARCH UNITS BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF REDCAD AND CISTER RESEARCH UNITS 
 * HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * REDCAD AND CISTER RESEARCH UNITS DISCLAIM ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND REDCAD AND CISTER RESEARCH UNITS HAVE NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 */
 /* Authors:    Maissa Ben Jamaa <mbenj@redcad.org>, Denis do Rosrio <dlr@isep.ipp.pt>
  *				Nouha Baccour <nabr@isep.ipp.pt>, Anis Koubaa <aska@isep.ipp.pt>,
  *				Mrio Alves <mjf@isep.ipp.pt>, Habib Youssef <habib.youssef@fsm.rnu.tn>, Leandro Becker <lbecker@das.ufsc.br>
  *				
  * Date: February 1 2010
  * Desc: ExpCtrApp v 1.0
 *              
 */ 
import java.awt.Color;
import java.awt.Paint;
import javax.swing.JPanel;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.SymbolAxis;
import org.jfree.chart.plot.PiePlot;
import org.jfree.chart.plot.XYPlot;
import org.jfree.data.DomainOrder;
import org.jfree.data.general.DatasetChangeListener;
import org.jfree.data.general.DatasetGroup;
import org.jfree.data.xy.XYZDataset;
import org.jfree.chart.renderer.GrayPaintScale;
import org.jfree.chart.renderer.PaintScale;
import org.jfree.chart.renderer.xy.XYBlockRenderer;
import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RefineryUtilities;
import org.jfree.chart.renderer.LookupPaintScale;
import org.jfree.chart.title.PaintScaleLegend;
import org.jfree.ui.RectangleEdge;
import org.jfree.ui.RectangleInsets;

import java.sql.ResultSet;
import java.util.List;
import java.util.ArrayList;
public class GraphPRR extends JPanel {
    private DBconnection db = new DBconnection();
    private List<String>  idSender = new ArrayList<String>();
    private List<String>  idReceiver = new ArrayList<String>();
    String expRun;
    String expId;
    public GraphPRR(String experimentId, String experimentRun, List sender, List receiver ) {
        super();

	idSender = sender;
	idReceiver = receiver;
	expId = experimentId;
	expRun = experimentRun;

        JPanel  chartPanel = createDemoPanel();
        chartPanel.setPreferredSize(new java.awt.Dimension (1200, 700));
        add(chartPanel);
    }
    private JFreeChart createChart(XYZDataset dataset) {
        NumberAxis xAxis = new NumberAxis("Sender");
        xAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
        xAxis.setLowerMargin(0.0);
        xAxis.setUpperMargin(0.0);
        NumberAxis yAxis = new NumberAxis("Receiver");
        yAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
        yAxis.setLowerMargin(0.0);
        yAxis.setUpperMargin(0.0);
        XYBlockRenderer renderer = new XYBlockRenderer();
        PaintScale scale = new GrayPaintScale(0.0, 1.0);
        renderer.setPaintScale(scale);
        XYPlot plot = new XYPlot(dataset, xAxis, yAxis, renderer);
        plot.setBackgroundPaint(Color.getHSBColor(255,153,5));
        plot.setDomainGridlinePaint(Color.white);
        plot.setRangeGridlinePaint(Color.white);
        plot.setForegroundAlpha(0.66f);
        plot.setAxisOffset(new RectangleInsets(5, 5, 5, 5));

        JFreeChart chart = new JFreeChart("PRR of motes", plot);
        chart.removeLegend();
        chart.setBackgroundPaint(Color.white);

		SymbolAxis scaleAxis = new SymbolAxis(null, new String[] {"0%", "100%" });
        scaleAxis.setRange(0.0, 1.0);
        scaleAxis.setPlot(new PiePlot());
        scaleAxis.setGridBandsVisible(false);
		PaintScaleLegend psl = new PaintScaleLegend(scale, scaleAxis);
        psl.setAxisOffset(2.0);
        psl.setPosition(RectangleEdge.BOTTOM);
        psl.setMargin(new RectangleInsets(5, 5, 15, 15));
        chart.addSubtitle(psl);
        return chart;
    }
    private XYZDataset createDataset() {
        return new XYZDataset() {
            public int getSeriesCount() {
                return idSender.size();
            }
            public int getItemCount(int sizeSender) {
                return idReceiver.size();
            }
            public Number getX(int sizeSender, int sizeReceiver) {
		return 10;
            }
            public double getXValue(int sizeSender, int sizeReceiver) {
                return Double.parseDouble(idSender.get(sizeSender).toString());
            }
            public Number  getY(int sizeSender, int sizeReceiver) {
		return 1;
            }
            public double getYValue(int sizeSender, int sizeReceiver) {
                return Double.parseDouble(idReceiver.get(sizeReceiver).toString());
            }
            public Number getZ(int sizeSender, int sizeReceiver) {
		return 1;
            }
            public double getZValue(int sizeSender, int sizeReceiver) {
	        String sql;
	        ResultSet result;
		int nbr_sent_packet = 0, count = 0;
		float prr = 0;
		if ((!idSender.get(sizeSender).toString().equals("1") && idReceiver.get(sizeReceiver).toString().equals("1")) || (idSender.get(sizeSender).toString().equals("1") && !idReceiver.get(sizeReceiver).toString().equals("1"))){
			db.open_a_connection();
			sql = "select exp_nbr_sent_packet from experiment where exp_id = '" + expId + "' and exp_run_nbr = '" + expRun +"';";
			result = db.select(sql);
			try {
		               	if (result.next()) {
				nbr_sent_packet = result.getInt(1);
		             	}
			} catch (Exception e) {e.printStackTrace();}
			sql = "SELECT exp_id FROM linkData WHERE exp_id = '" + expId + "' and exp_run_nbr = '" + expRun + "'";
			count = 0;
		
			result = db.select(sql + " and src_id = " + idSender.get(sizeSender) + " and rcv_id = " +idReceiver.get(sizeReceiver)+";");
			try {
	        		while (result.next()) {
        	        		count ++;
        		     	}
			} catch (Exception e) {e.printStackTrace();}
			if (count != 0){
				prr = (float) (count) / nbr_sent_packet;
			}
			db.close_a_connection();
		}
		return prr;
            }
            public void addChangeListener(DatasetChangeListener listener) {
           
 	    }
            public void removeChangeListener(DatasetChangeListener listener) {
         
    	    }
            public DatasetGroup getGroup() {
                return null;
            }
            public void setGroup(DatasetGroup group) {
             
 	    }
            public Comparable  getSeriesKey(int series) {
                return "prr";
            }
            public int indexOf(Comparable  seriesKey) {
                return 0;
            }
            public DomainOrder getDomainOrder() {
                return DomainOrder.ASCENDING;
            }
        };
    }
    public  JPanel createDemoPanel() {
        return new ChartPanel(createChart(createDataset()));
    }
}
