/*        
 * "Copyright (c) ReDCAD (Research Unit of Development and Control of Distributed Applications).
 * "Copyright (c) CISTER (Research  Centre in Real-Time Computing Systems) 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 *
 * IN NO EVENT SHALL REDCAD AND CISTER RESEARCH UNITS BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF REDCAD AND CISTER RESEARCH UNITS 
 * HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * REDCAD AND CISTER RESEARCH UNITS DISCLAIM ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND REDCAD AND CISTER RESEARCH UNITS HAVE NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 */
 /* Authors:    Maissa Ben Jamaa <mbenj@redcad.org>, Denis do Rosrio <dlr@isep.ipp.pt>
  *				Nouha Baccour <nabr@isep.ipp.pt>, Anis Koubaa <aska@isep.ipp.pt>,
  *				Mrio Alves <mjf@isep.ipp.pt>, Habib Youssef <habib.youssef@fsm.rnu.tn>, Leandro Becker <lbecker@das.ufsc.br>
  *				
  * Date: February 1 2010
  * Desc: ExpCtrApp v 1.0
 *              
 */ 
import java.sql.ResultSet;
import java.util.List;
import java.util.ArrayList;
import javax.swing.JFrame;
import java.awt.BorderLayout;
import java.awt.Color;
import javax.swing.JPanel;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.SymbolAxis;
import org.jfree.chart.plot.PiePlot;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.LookupPaintScale;
import org.jfree.chart.renderer.xy.XYBlockRenderer;
import org.jfree.chart.title.PaintScaleLegend;
import org.jfree.data.xy.DefaultXYZDataset;
import org.jfree.data.xy.XYZDataset;
import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RectangleEdge;
import org.jfree.ui.RectangleInsets;
import org.jfree.ui.RefineryUtilities;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

public class GraphRegion extends JPanel {
    private DBconnection db = new DBconnection();
    private List<String>  idSender = new ArrayList<String>();
    private List<String>  idReceiver = new ArrayList<String>();
    String expRun;
    String expId;
    
    public GraphRegion(String experimentId, String experimentRun, List sender, List receiver) {
        super();

	idSender = sender;
	idReceiver = receiver;
	expId = experimentId;
	expRun = experimentRun;

        JPanel chartPanel = createDemoPanel();
        chartPanel.setPreferredSize(new java.awt.Dimension(1230, 700));
        add(chartPanel);
    }

    private JFreeChart createChart(XYZDataset dataset) {
        NumberAxis xAxis = new NumberAxis("Sender");
        xAxis.setLowerMargin(0.0);
        xAxis.setUpperMargin(0.0);
        NumberAxis yAxis = new NumberAxis("Receiver");
        yAxis.setAutoRangeIncludesZero(false);
        yAxis.setInverted(true);
        yAxis.setLowerMargin(0.0);
        yAxis.setUpperMargin(0.0);
        yAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
        XYBlockRenderer renderer = new XYBlockRenderer();
        LookupPaintScale paintScale = new LookupPaintScale(0.5, 3.5, Color.black);
        paintScale.add(0.5, Color.red);
        paintScale.add(1.5, Color.orange);
        paintScale.add(2.5, Color.green);       
		paintScale.add(3.5, Color.white);
        renderer.setPaintScale(paintScale);
        XYPlot plot = new XYPlot(dataset, xAxis, yAxis, renderer);
        plot.setBackgroundPaint(Color.lightGray);
        plot.setDomainGridlinePaint(Color.white);
        plot.setRangeGridlinePaint(Color.white);
        plot.setForegroundAlpha(0.66f);
        plot.setAxisOffset(new RectangleInsets(5, 5, 5, 5));
        
		JFreeChart chart = new JFreeChart("Region of links", plot);
        chart.removeLegend();
        chart.setBackgroundPaint(Color.white);
        SymbolAxis scaleAxis = new SymbolAxis(null, new String[] {"", "Disconnected (0 >= PRR < 10 )", "Transitional (10 >= PRR < 90 )", "Connected (90 >= PRR <= 100 )"});
        scaleAxis.setRange(0.5, 3.5);
        scaleAxis.setPlot(new PiePlot());
        scaleAxis.setGridBandsVisible(false);
        PaintScaleLegend psl = new PaintScaleLegend(paintScale, scaleAxis);
        psl.setAxisOffset(5.0);
        psl.setPosition(RectangleEdge.BOTTOM);
        psl.setMargin(new RectangleInsets(5, 5, 5, 5));
        chart.addSubtitle(psl);
        return chart;
    }

    private static void setValue(double[][] data, int c, int r, double value) {
        data[0][(r - 0) * 60 + c] = c;
        data[1][(r - 0) * 60 + c] = r;
        data[2][(r - 0) * 60 + c] = value;
    }

    private XYZDataset createDataset() {
        double[] xvalues = new double[14 * 215];
        double[] yvalues = new double[14 * 215];       
        double[] zvalues = new double[14 * 215];
        double[][] data = new double[][] {xvalues, yvalues, zvalues};
       
        // set the default z-value to zero throughout the data array.
        for (int c = 0; c < idSender.size()+1; c++) {
            for (int r = 0; r < idReceiver.size()+1; r++) {
		if (c == r)
                    setValue(data, c, r, 3.5);
		else
		    setValue(data, c, r, 0.0);
            }
        }


	db.open_a_connection();
        String sql;
        ResultSet result;
	int nbr_sent_packet = 0, count = 0;
	float prr;
	sql = "select exp_nbr_sent_packet from experiment where exp_id = '" + expId + "' and exp_run_nbr = '" + expRun +"';";
	result = db.select(sql);
	try {
               	if (result.next()) {
			nbr_sent_packet = result.getInt(1);
             	}
	} catch (Exception e) {e.printStackTrace();}
	sql = "SELECT exp_id FROM linkData WHERE exp_id = '" + expId + "' and exp_run_nbr = '" + expRun + "'";
	for (int j=0; j<idSender.size(); j++){
	               for (int z=0; z<idReceiver.size(); z++){
			count = 0;
			if ((!idSender.get(j).toString().equals("1") && idReceiver.get(z).toString().equals("1")) || (idSender.get(j).toString().equals("1") && !idReceiver.get(z).toString().equals("1"))){
				result = db.select(sql + " and src_id = " + idSender.get(j) + " and rcv_id = " +idReceiver.get(z)+";");
				try {
		        		while (result.next()) {
	        	        		count ++;
	        		     	}
				} catch (Exception e) {e.printStackTrace();}
				if (count >= 0){
					prr = (float) (count * 100) / nbr_sent_packet;
					if (prr >= 0 && prr < 10)
						setValue(data, Integer.parseInt(idSender.get(j).toString()), Integer.parseInt(idReceiver.get(z).toString()), 1);
					else if (prr >= 10 && prr < 90)
						setValue(data, Integer.parseInt(idSender.get(j).toString()), Integer.parseInt(idReceiver.get(z).toString()), 2);
					else if (prr >= 90 && prr <= 100)
						setValue(data, Integer.parseInt(idSender.get(j).toString()), Integer.parseInt(idReceiver.get(z).toString()), 3);
				}
			}
		}
	}
        DefaultXYZDataset dataset = new DefaultXYZDataset();
        dataset.addSeries("Series 1", data);

	db.close_a_connection();
        return dataset;
    }

    public  JPanel createDemoPanel() {
        return new ChartPanel(createChart(createDataset()));
    }
}
