/*        
 * "Copyright (c) ReDCAD (Research Unit of Development and Control of Distributed Applications).
 * "Copyright (c) CISTER (Research  Centre in Real-Time Computing Systems) 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 *
 * IN NO EVENT SHALL REDCAD AND CISTER RESEARCH UNITS BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF REDCAD AND CISTER RESEARCH UNITS 
 * HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * REDCAD AND CISTER RESEARCH UNITS DISCLAIM ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND REDCAD AND CISTER RESEARCH UNITS HAVE NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 */
 /* Authors:    Maissa Ben Jamaa <mbenj@redcad.org>, Denis do Rosrio <dlr@isep.ipp.pt>
  *				Nouha Baccour <nabr@isep.ipp.pt>, Anis Koubaa <aska@isep.ipp.pt>,
  *				Mrio Alves <mjf@isep.ipp.pt>, Habib Youssef <habib.youssef@fsm.rnu.tn>, Leandro Becker <lbecker@das.ufsc.br>
  *				
  * Date: February 1 2010
  * Desc: ExpCtrApp v 1.0
 *              
 */ 
 

/** Simple data structure with three properties: country,
 *  comment, and flagFile. All are strings, and they are
 *  intended to represent a country that has a city or
 *  province named "Java", a comment about a more
 *  specific location within the country, and a path
 *  specifying an image file containing the country's flag.
 *  Used in examples illustrating custom models and cell
 *  renderers for JLists.
 *
 *  1998-99 Marty Hall, http://www.apl.jhu.edu/~hall/java/
 *  2009 Modified By Maissa Ben Jamaa
 */
public class NodeInfo {
  private String NodeId, Portnb, ImgFile;

  public NodeInfo(String NodeId, String Portnb,
		      String ImgFile) {
    setNodeId(NodeId);
    setPortnb(Portnb);
    setImgFile(ImgFile);
  }

  /** String representation used in printouts and in JLists */
  
  public String toString() {
    return("Telosb: ," + getNodeId() + ",on port : ," + getPortnb() + "");
  }
  
  /** Return country containing city or province named "Java". */
  
  public String getNodeId() {
    return(NodeId);
  }

  /** Specify country containing city or province named "Java". */
  
  public void setNodeId(String NodeId) {
    this.NodeId = NodeId;
  }

  /** Return comment about city or province named "Java".
   *  Usually of the form "near such and such a city".
   */
  
  public String getPortnb() {
    return(Portnb);
  }

  /** Specify comment about city or province named "Java". */

  public void setPortnb(String Portnb) {
    this.Portnb = Portnb;
  }
  
  /** Return path to image file of country flag. */
  
  public String getImgFile() {
    return(ImgFile);
  }

  /** Specify path to image file of country flag. */
  
  public void setImgFile(String ImgFile) {
    this.ImgFile = ImgFile;
  }
}
