/*        
 * "Copyright (c) ReDCAD (Research Unit of Development and Control of Distributed Applications).
 * "Copyright (c) CISTER (Research  Centre in Real-Time Computing Systems) 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 *
 * IN NO EVENT SHALL REDCAD AND CISTER RESEARCH UNITS BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF REDCAD AND CISTER RESEARCH UNITS 
 * HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * REDCAD AND CISTER RESEARCH UNITS DISCLAIM ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND REDCAD AND CISTER RESEARCH UNITS HAVE NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 */
 /* Authors:    Maissa Ben Jamaa <mbenj@redcad.org>, Denis do Rosrio <dlr@isep.ipp.pt>
  *				Nouha Baccour <nabr@isep.ipp.pt>, Anis Koubaa <aska@isep.ipp.pt>,
  *				Mrio Alves <mjf@isep.ipp.pt>, Habib Youssef <habib.youssef@fsm.rnu.tn>, Leandro Becker <lbecker@das.ufsc.br>
  *				
  * Date: February 1 2010
  * Desc: ExpCtrApp v 1.0
 *              
 */   

/** Simple custom cell renderer. The idea here is to augment
 *  the default one instead of building one from scratch. The
 *  advantage of this is that you don't have to handle the
 *  highlighting of the selected entries yourself, plus values that
 *  aren't of the new type you want to draw can be handled
 *  automatically. The disadvantage is that you are limited to a
 *  variation of a JLabel, which is what the default renderer returns.
 *  <P>
 *  Note that this method can get called lots and lots of times as you
 *  click on entries. But I don't want to keep generating new ImageIcon
 *  objects. So I make a Hashtable that associates previously displayed
 *  values with icons, reusing icons for entries that have been displayed
 *  already.
 *  <P>
 *  Note that in the first release of 1.2, the default renderer
 *  has a bug in that it doesn't clear out icons for later entries.
 *  so if you mix plain strings and ImageIcons in your JList, the
 *  plain strings still get an icon. Thus the call below that clears
 *  the old icon when the value is not a JavaLocation.
 *  <P>
 *  1998-99 Marty Hall, http://www.apl.jhu.edu/~hall/java/
 */
import javax.swing.*;
import java.awt.*;
import java.util.*;
public class NodeInfoRenderer extends DefaultListCellRenderer {
  private Hashtable iconTable = new Hashtable();
  
  public Component getListCellRendererComponent(JList list,
                                                Object value,
                                                int index,
                                                boolean isSelected,
                                                boolean hasFocus) {
    JLabel label =
      (JLabel)super.getListCellRendererComponent(list,
                                                 value,
                                                 index,
                                                 isSelected,
                                                 hasFocus);
    if (value instanceof NodeInfo) {
      NodeInfo telosb = (NodeInfo)value;
      ImageIcon icon = (ImageIcon)iconTable.get(value);
      if (icon == null) {
        icon = new ImageIcon(telosb.getImgFile());
        iconTable.put(value, icon);
      }
      label.setIcon(icon);
    } else {
      // Clear old icon; needed in 1st release of JDK 1.2
      label.setIcon(null); 
    }
    return(label);
  }
}
